package config

import (
	"context"
	"encoding/json"
	"game/common/config"
	"github.com/fox/fox/db"
	"github.com/fox/fox/log"
)

const (
	gateKey      = "gate_config"
	gateAddress1 = "114.132.124.145:5100"
	gateAddress2 = "114.132.124.145:5101"
)

var Command *config.Command
var Cfg *config.Common[GateConfig]

type GateConfig struct {
	Address []string `json:"address"` // 网关地址
}

func initLog() {
	log.Open("gate.log", log.DebugL)
}

func LoadConfig(GitCommit, GitBranch, BuildDate string) {
	Command = config.ParseCommand()
	initLog()
	rdb, err := db.InitRedis(Command.RedisPassword, Command.RedisHost, Command.RedisPort, 0)
	if err != nil {
		log.Error(err.Error())
		return
	}
	defer func() { _ = rdb.Close() }()
	Cfg, err = config.LoadCommonConfig[GateConfig](rdb, GitCommit, GitBranch, BuildDate)
	if err != nil {
		log.Error(err.Error())
		return
	}
	if err = config.LoadSpecialConfig[GateConfig](rdb, gateKey, Cfg); err != nil {
		log.DebugF("load config:empty etcd key")
		Cfg.Special = &GateConfig{
			Address: []string{gateAddress1, gateAddress2},
		}
		if bs, err := json.Marshal(&Cfg.Special); err == nil {
			err = rdb.Set(context.Background(), gateKey, string(bs), 0).Err()
		}
	}
	log.DebugF("load common config success")
}
